#####################
### EXPERIMENT 1
#####################
source('~/Documents/Data/summarySE_code.R', chdir = TRUE)
library(ggplot2)
library(car)
library(lme4)
library(nlme)
library(lmerTest)
source('~/Documents/Data/posthoc.tgh_code.R', chdir = TRUE)
########################

#Read in data - make .xlsx file into csv
tenrds <- read.csv("/Experiment1.csv", header=TRUE)
tenrds
str(tenrds)

table_tenrds_daily <- summarySE(tenrds, measurevar="PCIS_daily", groupvars=c("group","SP"), na.rm=TRUE)
table_tenrds_daily


###########################
#testing effect of round

###full model with random effect
test1 <- lmer(PCIS~group + SP + (1|round), REML=F, data=tenrds, na.action = na.exclude)
summary(test1)
anova(test1)

##null model without random effect
test2 <- lm(PCIS~group + SP, data=tenrds, na.action=na.exclude)
summary(test2)
anova(test2)

anova(test1, test2)
#no difference in two models

##########
### NOTE: performed test on all 4 species separately,
###       and no effect of round (see below)
#########


######################
#Graphs
######################

#all data with error bars
ggplot(table_tenrds_daily, aes(x=group, y=PCIS_daily)) +
  geom_errorbar(aes(ymin=PCIS_daily-se, ymax=PCIS_daily+se, colour=SP), width=0.1) +
  geom_point(aes(colour=SP)) +
  theme_bw() + theme(text = element_text(size=20, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) +  
  ylab("Per Capita Interaction Strength") + xlab(" ")

#S. purpuratus (urchin)
ggplot(table_tenrds_daily[table_tenrds_daily$SP=="UR",], aes(x=group, y=PCIS_daily)) +
  geom_errorbar(aes(ymin=PCIS_daily-se, ymax=PCIS_daily+se), width=0.1, colour="mediumpurple4") +
  geom_point(aes(size=15), colour="mediumpurple4") +
  theme_bw() + theme(text = element_text(size=36, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = 	element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) +
  ylim(-0.004,0.0003) +
  ylab("Per Capita Interaction Strength") + xlab(" ")

#T. brunnea (brown turban snail)
ggplot(table_tenrds_daily[table_tenrds_daily$SP=="TB",], aes(x=group, y=PCIS_daily)) +
  geom_errorbar(aes(ymin=PCIS_daily-se, ymax=PCIS_daily+se), colour="saddlebrown", width=0.1) +
  geom_point(aes(size=15), colour="saddlebrown") +
  theme_bw() + theme(text = element_text(size=36, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = 	element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) + 
  ylim(-0.02,0) +
  ylab("Per Capita Interaction Strength") + xlab(" ")

#I. resecata (isopod)
ggplot(table_tenrds_daily[table_tenrds_daily$SP=="IR",], aes(x=group, y=PCIS_daily)) +
  geom_errorbar(aes(ymin=PCIS_daily-se, ymax=PCIS_daily+se), colour="olivedrab4", width=0.1) +
  geom_point(aes(size=15), colour="olivedrab4") +
  theme_bw() + theme(text = element_text(size=36, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = 	element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) +
  ylim(-0.004,0.0003) +
  ylab("Per Capita Interaction Strength") + xlab(" ")

#P. humeralis (amphipod)
ggplot(table_tenrds_daily[table_tenrds_daily$SP=="AM",], aes(x=group, y=PCIS_daily)) +
  geom_errorbar(aes(ymin=PCIS_daily-se, ymax=PCIS_daily+se), colour="black", width=0.1) +
  geom_point(aes(size=15), colour="black") +
  theme_bw() + theme(text = element_text(size=36, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = 	element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) + 
  ylim(-0.004,0.0003) +
  ylab("Per Capita Interaction Strength") + xlab(" ")


#PCIS graph ("present" vs "future" = Ambient and Combo treatments on one graph)
subtenrds <- subset(tenrds, (tenrds$group == "1Ambient" | tenrds$group == "4Combo"))

#reorder x axis so species are in order I want them to be
subtenrds$SP <- as.character(subtenrds$SP)
subtenrds$SP <- factor(subtenrds$SP, levels=unique(subtenrds$SP))
subtenrds$SP <- factor(subtenrds$SP, levels=c("TB", "IR", "UR", "AM"))

table_pcis_fig <- summarySE(subtenrds, measurevar="PCIS_daily", groupvars=c("group","SP"), na.rm=TRUE)
table_pcis_fig

ggplot(table_pcis_fig, aes(x=SP, y=PCIS_daily)) +
  geom_errorbar(aes(ymin=PCIS_daily-se, ymax=PCIS_daily+se), width=0.1) +
  geom_point(aes(colour=group), size=5, alpha=0.7) +
  scale_color_manual(values=c("steelblue2","tomato2")) +
  theme_bw() + theme(text = element_text(size=36, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) + 
  ylim(-0.015,0) +
  ylab("Per Capita Interaction Strength") + xlab(" ")


#Impact graph
impact_fig <- read.csv("/Experiment1_Impact.csv", header=TRUE)
impact_fig
str(impact_fig)

#reorder x axis so species are in order I want them to be
impact_fig$SP <- as.character(impact_fig$SP)
impact_fig$SP <- factor(impact_fig$SP, levels=unique(impact_fig$SP))
impact_fig$SP <- factor(impact_fig$SP, levels=c("TB", "IR", "UR", "AM"))

ggplot(impact_fig, aes(x=SP, y=Impact)) +
  geom_errorbar(aes(ymin=Impact-Impact_se, ymax=Impact+Impact_se), width=0.1) +
  geom_point(aes(colour=group), size=5, alpha=0.7) +
  scale_color_manual(values=c("tomato2", "steelblue2")) +
  theme_bw() + theme(text = element_text(size=36, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) + 
  ylim(-0.15,0) +
  ylab("Per Capita Interaction Strength") + xlab(" ")




####################
#Stats analyses
####################


###############
# Urchin
###############

UR <- na.exclude(subset(tenrds[tenrds$SP=="UR",]))
UR

###full model with random effect
test1 <- lmer(PCIS~group*tempval + (1|round), REML=F, data=UR, na.action = na.exclude)
summary(test1)
anova(test1)

##null model without random effect
test2 <- lm(PCIS~group*tempval, data=UR, na.action=na.exclude)
summary(test2)
anova(test2)

anova(test1, test2)
#no difference in two models

#explore basic model that makes sense
anovaUR <- aov(PCIS~group*tempval, data=tenrds[tenrds$SP=="UR",])
summary(anovaUR)

anovaUR_resids <- residuals(anovaUR)
plot(anovaUR_resids)
shapiro.test(anovaUR_resids)
leveneTest(PCIS~group, data=tenrds[tenrds$SP=="UR",], center=mean)
## shapiro test not significant but Levene's test is


#playing around with different variance structures (due to Levene's test showing
# heterogeneity of variances)
M.lmUR <- gls(PCIS~group*tempval, data=UR)
summary(M.lmUR)

vf1FixedUR <- varFixed(~PCIS)
M.gls1UR <- gls(PCIS~group*tempval,
                weights = vf1FixedUR, data=UR)

vf2UR <- varIdent(form= ~1|group)
M.gls2UR <- gls(PCIS~group*tempval, data=UR,
                weights = vf2UR)
summary(M.gls2UR)

vf3UR <- varPower(form = ~tempval)
M.gls3UR <- gls(PCIS~group*tempval, data=UR,
                weights = vf3UR)

vf4UR <- varComb(varIdent(form= ~ 1|group),
                 varExp(form= ~tempval))
M.gls4UR <- gls(PCIS~group*tempval, data=UR,
                weights = vf4UR)
anova(M.lmUR, M.gls1UR, M.gls2UR, M.gls3UR, M.gls4UR)
## lm and varPower models best

## building sequential models to be sure if tempval and/or a variance structure 
## should be added
m1UR <- gls(PCIS~group, data=UR)
summary(m1UR)

m2UR <- gls(PCIS~group + tempval, data=UR)
summary(m2UR)

m3UR <- gls(PCIS~group + tempval + group:tempval, data=UR)
summary(m3UR)

m4UR <- gls(PCIS~group, data=UR,
            weights=vf3UR)
summary(m4UR)

m5UR <- gls(PCIS~group + tempval, data=UR,
            weights=vf3UR)
summary(m5UR)

m6UR <- gls(PCIS~group + tempval + group:tempval, data=UR,
            weights=vf3UR)
summary(m6UR)

## use maximum likelihood
m1mlUR <- update(m1UR, .~., method="ML")
m2mlUR <- update(m2UR, .~., method="ML")
m3mlUR <- update(m3UR, .~., method="ML")
m4mlUR <- update(m4UR, .~., method="ML")
m5mlUR <- update(m5UR, .~., method="ML")
m6mlUR <- update(m6UR, .~., method="ML")

anova(m1mlUR, m2mlUR, m3mlUR, m4mlUR, m5mlUR, m6mlUR)
##### m1, m2, m3 lowest AICs. Choose m1 (simplest model with no temp or var structure)

URmodel <- aov(PCIS~group, data=UR)
plot(URmodel)
URmodel_resids <- residuals(URmodel)
plot(URmodel_resids)
## Since variance unequal (see above), run Welch's ANOVA (Does not assume equal variances)

URmodel2 <- lm(PCIS~ph*oxy, data=UR)
summary(URmodel2)
#no interaction between ph and oxygen

oneway.test(PCIS~group, data=tenrds[tenrds$SP=="UR",])

#kruskal.test(PCIS~group, data=tenrds[tenrds$SP=="UR",])
#Kruskal Wallis test does not assume normality but shows same results

posthoc.tgh(UR$PCIS, UR$group, method=c("games-howell"))


#################
# Brown turban snail
#################

TB <- na.exclude(subset(tenrds[tenrds$SP=="TB",]))
TB

###full model with random effect
test1 <- lmer(PCIS~group*tempval + (1|round), REML=F, data=TB, na.action = na.exclude)
summary(test1)
anova(test1)

##null model without random effect
test2 <- lm(PCIS~group*tempval, data=TB, na.action=na.exclude)
summary(test2)
anova(test2)

anova(test1, test2)
#no difference in two models


#explore basic model that makes sense
anovaTB <- aov(PCIS~group*tempval, data=tenrds[tenrds$SP=="TB",])
summary(anovaTB)

anovaTB_resids <- residuals(anovaTB)
plot(anovaTB2_resids)
shapiro.test(anovaTB2_resids)
leveneTest(PCIS~group, data=tenrds[tenrds$SP=="TB",], center=mean)
## shapiro test barely sig & Levene's test sig


#playing around with different variance structures (due to Levene's test showing
# heterogeneity of variances)
M.lmTB <- gls(PCIS~group*tempval, data=TB)
summary(M.lmTB)

vf1FixedTB <- varFixed(~PCIS)
M.gls1TB <- gls(PCIS~group*tempval,
                weights = vf1FixedTB, data=TB)

vf2TB <- varIdent(form= ~1|group)
M.gls2TB <- gls(PCIS~group*tempval, data=TB,
                weights = vf2TB)

vf3TB <- varPower(form = ~tempval)
M.gls3TB <- gls(PCIS~group*tempval, data=TB,
                weights = vf3TB)

vf4TB <- varComb(varIdent(form= ~ 1|group),
                 varExp(form= ~tempval))
M.gls4TB <- gls(PCIS~group*tempval, data=TB,
                weights = vf4TB)
anova(M.lmTB, M.gls1TB, M.gls2TB, M.gls3TB, M.gls4TB)
## varPower, fixed, lm models best

anova(M.gls1TB, M.gls3TB)
#can't compare lm model with others, but no diff between varPower and fixed models
#so most likely no diff in lm and fixed based on AIC


## building sequential models 
m1TB <- gls(PCIS~group, data=TB)
summary(m1TB)

m2TB <- gls(PCIS~group + tempval, data=TB)
summary(m2TB)

m3TB <- gls(PCIS~group + tempval + group:tempval, data=TB)
summary(m3TB)

## use maximum likelihood 
m1mlTB <- update(m1TB, .~., method="ML")
m2mlTB <- update(m2TB, .~., method="ML")
m3mlTB <- update(m3TB, .~., method="ML")

anova(m1mlTB, m2mlTB, m3mlTB)
##### All models same. Go with simplest model with no temp added

TBmodel <- aov(PCIS~group, data=TB)
plot(TBmodel)
TBmodel_resids <- residuals(TBmodel)
plot(TBmodel_resids)
shapiro.test(TBmodel_resids)
leveneTest(PCIS~group, data=tenrds[tenrds$SP=="TB",], center=mean)
#Shapiro and Levene's test significant but residuals look pretty good so run Welch's ANOVA

TBmodel2 <- lm(PCIS~ph*oxy, data=TB)
summary(TBmodel2)
#no interaction between ph and oxy

oneway.test(PCIS~group, data=tenrds[tenrds$SP=="TB",])

#kruskal.test(PCIS~group, data=tenrds[tenrds$SP=="TB",])
#kruskal wallis test does not assume normality but shows same results

posthoc.tgh(TB$PCIS, TB$group, method=c("games-howell"))


#################
# Isopod
#################
IR <- na.exclude(subset(tenrds[tenrds$SP=="IR",]))
IR

###full model with random effect
test1 <- lmer(PCIS~group*tempval + (1|round), REML=F, data=IR, na.action = na.exclude)
summary(test1)
anova(test1)

##null model without random effect
test2 <- lm(PCIS~group*tempval, data=IR, na.action=na.exclude)
summary(test2)
anova(test2)

anova(test1, test2)
#no difference in two models

#explore a basic model that makes sense
anovaIR <- aov(PCIS~group*tempval, data=tenrds[tenrds$SP=="IR",])
summary(anovaIR)

anovaIR2_resids <- residuals(anovaIR2)
plot(anovaIR2_resids)
shapiro.test(anovaIR2_resids)
leveneTest(PCIS~group, data=tenrds[tenrds$SP=="IR",], center=mean)
## shapiro test & Levene's test sig

#playing around with different variance structures (due to Levene's test showing
# heterogeneity of variances)
M.lmIR <- gls(PCIS~group*tempval, data=IR)
summary(M.lmIR)

vf1FixedIR <- varFixed(~PCIS)
M.gls1IR <- gls(PCIS~group*tempval,
                weights = vf1FixedIR, data=IR)

vf2IR <- varIdent(form= ~1|group)
M.gls2IR <- gls(PCIS~group*tempval, data=IR, 
                weights = vf2IR)

vf3IR <- varPower(form = ~tempval)
M.gls3IR <- gls(PCIS~group*tempval, data=IR,
                weights = vf3IR)

vf4IR <- varComb(varIdent(form= ~ 1|group),
                 varExp(form= ~tempval))
M.gls4IR <- gls(PCIS~group*tempval, data=IR,
                weights = vf4IR)
anova(M.lmIR, M.gls2IR, M.gls3IR, M.gls4IR)
##lm model the best


## building sequential models 
m1IR <- gls(PCIS~group, data=IR)
summary(m1IR)

m2IR <- gls(PCIS~group + tempval, data=IR)
summary(m2IR)

m3IR <- gls(PCIS~group + tempval + group:tempval, data=IR)
summary(m3IR)

## use maximum likelihood 
m1mlIR <- update(m1IR, .~., method="ML")
m2mlIR <- update(m2IR, .~., method="ML")
m3mlIR <- update(m3IR, .~., method="ML")

anova(m1mlIR, m2mlIR, m3mlIR)
##### m1 and m2 equivalent

lm1IR <- lm(PCIS~group, data=IR)
lm2IR <- lm(PCIS~group + tempval, data=IR)
lm3IR <- lm(PCIS~group + tempval + group:tempval, data=IR)
anova(lm1IR, lm2IR)
anova(lm1IR, lm3IR)
anova(lm2IR, lm3IR)
#lm models show the same thing - choose an ANOVA (no temp added)

IRmodel <- aov(PCIS~group, data=IR)
plot(IRmodel)
IRmodel_resids <- residuals(IRmodel)
plot(IRmodel_resids)
shapiro.test(IRmodel_resids)
leveneTest(PCIS~group, data=tenrds[tenrds$SP=="IR",], center=mean)
## shapiro test & Levene's test significant but residuals look good (one outlier) so run Welch's ANOVA

IRmodel2 <- lm(PCIS~ph*oxy, data=IR)
summary(IRmodel2)
IRmodel2$coefficients
#interaction between ph and oxygen

oneway.test(PCIS~group, data=tenrds[tenrds$SP=="IR",])

#kruskal.test(PCIS~group, data=tenrds[tenrds$SP=="IR",])
#kruskal wallis test does not assume normality but shows same results

games.howell(IR$group, IR$PCIS)


###################
# Amphipod
###################

AM <- na.exclude(subset(tenrds[tenrds$SP=="AM",]))
AM

###full model with random effect
test1 <- lmer(PCIS~group*tempval + (1|round), REML=F, data=AM, na.action = na.exclude)
summary(test1)
anova(test1)

##null model without random effect
test2 <- lm(PCIS~group*tempval, data=AM, na.action=na.exclude)
summary(test2)
anova(test2)

anova(test1, test2)
#no difference in two models

#explore basic model that makes sense
anovaAM <- aov(PCIS~group*tempval, data=tenrds[tenrds$SP=="AM",])
summary(anovaAM)

anovaAM2_resids <- residuals(anovaAM2)
plot(anovaAM2_resids)
shapiro.test(anovaAM2_resids)
leveneTest(PCIS~group, data=tenrds[tenrds$SP=="AM",], center=mean)
## shapiro test & Levene's test significant


#playing around with different variance structures (due to Levene's test showing
# heterogeneity of variances)
M.lmAM <- gls(PCIS~group*tempval, data=AM)
summary(M.lmAM)

vf1FixedAM <- varFixed(~PCIS)
M.gls1AM <- gls(PCIS~group*tempval,
                weights = vf1FixedAM, data=AM)

vf2AM <- varIdent(form= ~1|group)
M.gls2AM <- gls(PCIS~group*tempval, data=AM,
                weights = vf2AM)
summary(M.gls2AM)

vf3AM <- varPower(form = ~tempval)
M.gls3AM <- gls(PCIS~group*tempval, data=AM,
                weights = vf3AM)

vf4AM <- varComb(varIdent(form= ~ 1|group),
                 varExp(form= ~tempval))
M.gls4AM <- gls(PCIS~group*tempval, data=AM,
                weights = vf4AM)
anova(M.lmAM, M.gls1AM, M.gls2AM, M.gls3AM, M.gls4AM)
## varPower and lm model best 

### building sequential models 
m1AM <- gls(PCIS~group, data=AM)
summary(m1AM)

m2AM <- gls(PCIS~group + tempval, data=AM)
summary(m2AM)

m3AM <- gls(PCIS~group + tempval + group:tempval, data=AM)
summary(m3AM)

## use maximum likelihood
m1mlAM <- update(m1AM, .~., method="ML")
m2mlAM <- update(m2AM, .~., method="ML")
m3mlAM <- update(m3AM, .~., method="ML")

anova(m1mlAM, m2mlAM, m3mlAM)
##### All close. Which to choose? Compare lm models instead of gls

lm1AM <- lm(PCIS~group, data=AM)
lm2AM <- lm(PCIS~group + tempval, data=AM)
lm3AM <- lm(PCIS~group + tempval + group:tempval, data=AM)
anova(lm1AM, lm2AM)
anova(lm1AM, lm3AM)
anova(lm2AM, lm3AM)
#Choose lm2 (model with temp added) (and based off of first lm model run - see above, temp sig)


AMmodel <- lm(PCIS~group+tempval, data=AM)
summary(AMmodel)
plot(AMmodel)
AMmodel_resids <- residuals(AMmodel)
plot(AMmodel_resids)
shapiro.test(AMmodel_resids)
leveneTest(PCIS~group, data=tenrds[tenrds$SP=="AM",], center=mean)
### shapiro test & Levene's test significant but residuals look good (one outlier)

AMmodel2 <- lm(PCIS~ph*oxy+tempval, data=AM)
summary(AMmodel2)
#no interaction between oxy and pH

AM.lsm1 <- emmeans(AMmodel, "group")
pairs(AM.lsm1)
plot(AM.lsm1, comparisons=TRUE, alpha=0.05)
cld(AM.lsm1, alpha=0.05)


##############
## Analyses with dead individuals excluded
#############

live <- tenrds[tenrds$mortality_acc=="0",]

table_tenrds_live <- summarySE(live, measurevar="PCIS_daily", groupvars=c("group","SP"), na.rm=TRUE)
table_tenrds_live

ggplot(table_tenrds_live[table_tenrds_live$SP=="AM",], aes(x=group, y=PCIS_daily)) +
  geom_errorbar(aes(ymin=PCIS_daily-se, ymax=PCIS_daily+se), colour="black", width=0.1) +
  geom_point(aes(size=15), colour="black") +
  theme_bw() + theme(text = element_text(size=36, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = 	element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) + 
  ylim(-0.004,0.0003) +
  ylab("Per Capita Interaction Strength") + xlab(" ")

ggplot(table_tenrds_live[table_tenrds_live$SP=="IR",], aes(x=group, y=PCIS_daily)) +
  geom_errorbar(aes(ymin=PCIS_daily-se, ymax=PCIS_daily+se), colour="olivedrab4", width=0.1) +
  geom_point(aes(size=15), colour="olivedrab4") +
  theme_bw() + theme(text = element_text(size=36, face="bold"), 
                     panel.border = element_blank(), panel.grid.major = element_blank(), 
                     panel.grid.minor = 	element_blank(), axis.line.x = element_line(color="black"),
                     axis.line.y = element_line(color="black")) +
  ylim(-0.004,0.0003) +
  ylab("Per Capita Interaction Strength") + xlab(" ")


###################
# Amphipod - dead individuals exc.
###################

AM_live <- na.exclude(subset(live[live$SP=="AM",]))
AM_live

###full model with random effect
test1 <- lmer(PCIS~group*tempval + (1|round), REML=F, data=AM_live, na.action = na.exclude)
summary(test1)
anova(test1)

##null model without random effect
test2 <- lm(PCIS~group*tempval, data=AM_live, na.action=na.exclude)
summary(test2)
anova(test2)

anova(test1, test2)
#no difference in two models


AMmodel_live <- lm(PCIS~group+tempval, data=AM_live)
summary(AMmodel_live)
plot(AMmodel_live)
AMmodel_live_resids <- residuals(AMmodel_live)
plot(AMmodel_live_resids)

AMmodel2_live <- lm(PCIS~ph*oxy+tempval, data=AM_live)
summary(AMmodel2_live)
#no interaction between oxy and pH (same as full dataset)

#Multiple comparisons test using least square means
AM.lsm_live <- emmeans(AMmodel_live, "group")
pairs(AM.lsm_live)
plot(AM.lsm_live, comparisons=TRUE, alpha=0.05)
cld(AM.lsm_live, alpha=0.05)
#Shows A B AB B (versus A B A B in full dataset but likely from small sample size 
#                   -But same trend of acidification no sig effect & hypoxia dominance)


#################
# Isopods - dead individuals exc.
#################

IR_live <- na.exclude(subset(live[live$SP=="IR",]))
IR_live

###full model with random effect
test1 <- lmer(PCIS~group*tempval + (1|round), REML=F, data=IR_live, na.action = na.exclude)
summary(test1)
anova(test1)

##null model without random effect
test2 <- lm(PCIS~group*tempval, data=IR_live, na.action=na.exclude)
summary(test2)
anova(test2)

anova(test1, test2)
#no difference in two models


IRmodel_live <- aov(PCIS~group, data=IR_live)
plot(IRmodel_live)
IRmodel_live_resids <- residuals(IRmodel_live)
plot(IRmodel_live_resids)
shapiro.test(IRmodel_resids)
leveneTest(PCIS~group, data=IR_live, center=mean)
## shapiro test & Levene's test significant but residuals look good (one outlier) so run Welch's ANOVA

IRmodel2_live <- lm(PCIS~ph*oxy, data=IR_live)
summary(IRmodel2_live)
IRmodel2_live$coefficients
#interaction between ph and oxygen (like full dataset)

oneway.test(PCIS~group, data=IR_live)

#kruskal.test(PCIS~group, data=IR_live)
#kruskal wallis test does not assume normality but shows same results

posthoc.tgh(IR_live$PCIS, IR_live$group, method=c("games-howell"))
# shows A B AC BC (same as full dataset)

############################################